@@ -17,7 +17,7 @@ def api(func):
 def exception_json(func):
     def wrap(request, *args, **kwargs):
         try:
-            func(request, *args, **kwargs)
+            return func(request, *args, **kwargs)
         except:
             return ArcReturnJSONObject(False, 'exception_json').json_response()
     return wrap
\ No newline at end of file
